Keywords: Supreme Court Opinions

Home > Virginia's Court System > Supreme Court of Virginia > Supreme Court of Virginia Opinions

# Supreme Court of Virginia Opinions

As of February 8, 2008 all opinions are Adobe Acrobat PDF documents. The Adobe Acrobat Viewer (free from Adobe) allows you to view and print PDF documents.

Click here for Supreme Court of Virginia Opinions Revised within the last six-months

030592 King George County Service Authority v. Presidential Service Company 03/05/2004 The circuit court was correct in specifically enforcing an agreement for the purchase of a private water company's existing water system by a county service authority under an agreement ratified by the authority's board, but erred in directing the authority to purchase other water and sewer system facilities because there was no resolution of the authority's board authorizing or ratifying a further agreement. The decree is affirmed in part and reversed in part.

030634 Harrison-Wyatt LLC v. Ratliff 03/05/2004 The trial court correctly ruled that where a surface owner of a tract of land, or his predecessor-in-title, has conveyed all the coal in and under his land, title to the coal bed methane gas in the tract has not passed to the coal owner along with the coal. The trial court's judgment is affirmed. (Revised 4/1/04)

030637 Washington v. United Parcel Service 03/05/2004 In a workers' compensation appeal, the Court of Appeals erred in addressing an issue of causal connection that was not properly before that court and not properly before the Commission. As a result, there was no basis for concluding that the claimant would be unjustly enriched by receiving benefits to which he was not entitled. A prior award of benefits remains valid, and the refusal to assess a 20% penalty was error. The judgment is reversed and the case is remanded for further proceedings. (Revised 3/8/04)

942223 Royal v. Commonwealth 06/09/1995 The defendant was indicted for the capital murder of a police officer and use of a firearm in the commission of murder. He entered pleas of guilty on both charges and received sentences of death for the capital murder charge and three years imprisonment for the firearms charge. The defendant's appeal of the imposition of the death penalty is considered along with the automatic review of the death sentence to which he is entitled under Code § 17.110.1. No reversible error is found among the issues presented; the judgment of the trial court is affirmed.

Home | Virginia's Court System | Online Services | Case Status and Information | Court Administration | Directories | Forms | Judicial Branch Agencies | Programs